@@ -10,7 +10,9 @@ class IEnvironmentManager:
     __metaclass__ = ABCMeta
 
     @abstractmethod
-    def install_environment(self, collection_solution: ICollectionSolution) -> IEnvironment:
+    def install_environment(
+        self, collection_solution: ICollectionSolution
+    ) -> IEnvironment:
         raise NotImplementedError
 
     @abstractmethod
@@ -42,5 +44,5 @@ class IEnvironmentManager:
         raise NotImplementedError
 
     @abstractmethod
-    def get_conda_manager(self):
+    def get_package_manager(self):
         raise NotImplementedError
