@@ -12,9 +12,14 @@ from album.core.model.catalog import Catalog, retrieve_index_files_from_src
 from album.core.model.catalog_index import CatalogIndex
 from album.core.model.catalog_updates import CatalogUpdates, SolutionChange, ChangeType
 from album.core.model.collection_index import CollectionIndex
+from album.core.model.db_version import DBVersion
 from album.core.model.default_values import DefaultValues
 from album.core.utils.operations.dict_operations import str_to_dict
-from album.core.utils.operations.file_operations import force_remove, copy, get_dict_from_json
+from album.core.utils.operations.file_operations import (
+    force_remove,
+    copy,
+    get_dict_from_json,
+)
 from album.core.utils.operations.resolve_operations import dict_to_coordinates
 from album.runner import album_logging
 
@@ -33,7 +38,9 @@ class CatalogHandler(ICatalogHandler):
 
         # cache catalog always of type direct, deployment not possible anyways
         catalog_meta_information = self.create_new_metadata(local_path, name, "direct")
-        catalog = self._create_catalog_from_src(local_path, catalog_meta_information, "main", deletable=False)
+        catalog = self._create_catalog_from_src(
+            local_path, catalog_meta_information, "main", deletable=False
+        )
         self._add_to_index(catalog)
         self.album.migration_manager().load_index(catalog)
         self._update_collection_from_catalog(catalog)
@@ -41,9 +48,13 @@ class CatalogHandler(ICatalogHandler):
     def add_initial_catalogs(self):
         self.create_cache_catalog()
         initial_catalogs = self.album.configuration().get_initial_catalogs()
-        initial_catalogs_branch_name = self.album.configuration().get_initial_catalogs_branch_name()
+        initial_catalogs_branch_name = (
+            self.album.configuration().get_initial_catalogs_branch_name()
+        )
         for catalog in initial_catalogs.keys():
-            self.add_by_src(str(initial_catalogs[catalog]), initial_catalogs_branch_name[catalog]).dispose()
+            self.add_by_src(
+                str(initial_catalogs[catalog]), initial_catalogs_branch_name[catalog]
+            ).dispose()
 
     def add_by_src(self, source, branch_name="main") -> Catalog:
         # source can be path or url
@@ -57,26 +68,34 @@ class CatalogHandler(ICatalogHandler):
             module_logger().warning("Cannot add catalog twice! Doing nothing...")
             return self._as_catalog(catalog_dict)
 
-        catalog_meta_information = self._retrieve_catalog_meta_information(source, branch_name)
+        catalog_meta_information = self._retrieve_catalog_meta_information(
+            source, branch_name
+        )
+        catalog_dict = self._get_collection_index().get_catalog_by_name(catalog_meta_information["name"])
+        if catalog_dict:
+            module_logger().warning("Cannot add catalog twice! Doing nothing...")
+            return self._as_catalog(catalog_dict)
 
-        catalog = self._create_catalog_from_src(source, catalog_meta_information, branch_name)
+        catalog = self._create_catalog_from_src(
+            source, catalog_meta_information, branch_name
+        )
 
         # always keep the local copy up to date
         if not catalog.is_cache():
             self.album.migration_manager().migrate_catalog_index_db(
                 catalog.index_file_path(),  # the path to the catalog
-                catalog_meta_information["version"],  # eventually outdated remote version
-                CatalogIndex.version  # current version in the library
+                DBVersion.from_string(catalog_meta_information["version"]),  # eventually outdated remote version
+                DBVersion.from_string(DefaultValues.catalog_index_db_version.value)
             )
 
         self._add_to_index(catalog)
         self._create_catalog_cache_if_missing(catalog)
         self.album.migration_manager().load_index(catalog)
 
-        module_logger().info('Catching catalog content..')
+        module_logger().info("Catching catalog content..")
         self._update(catalog)
         self._update_collection_from_catalog(catalog)
-        module_logger().info('Added catalog %s!' % source)
+        module_logger().info("Added catalog %s!" % source)
 
         return catalog
 
@@ -87,7 +106,7 @@ class CatalogHandler(ICatalogHandler):
             str(catalog.path()),
             int(catalog.is_deletable()),
             str(catalog.branch_name()),
-            str(catalog.type())
+            str(catalog.type()),
         )
         catalog.set_catalog_id(catalog_id)
         return catalog.catalog_id()
@@ -95,7 +114,7 @@ class CatalogHandler(ICatalogHandler):
     def get_by_id(self, catalog_id) -> Catalog:
         catalog = self._get_collection_index().get_catalog(catalog_id)
         if not catalog:
-            raise LookupError("Catalog with id \"%s\" not configured!" % catalog_id)
+            raise LookupError('Catalog with id "%s" not configured!' % catalog_id)
         return self._as_catalog(catalog)
 
     def _get_collection_index(self):
@@ -105,7 +124,7 @@ class CatalogHandler(ICatalogHandler):
         src = str(src)
         catalog_dict = self._get_collection_index().get_catalog_by_src(src)
         if not catalog_dict:
-            raise LookupError("Catalog with src \"%s\" not configured!" % src)
+            raise LookupError('Catalog with src "%s" not configured!' % src)
         return self._as_catalog(catalog_dict)
 
     def get_by_name(self, name) -> Catalog:
@@ -113,14 +132,14 @@ class CatalogHandler(ICatalogHandler):
         name = str(name)
         catalog_dict = self._get_collection_index().get_catalog_by_name(name)
         if not catalog_dict:
-            raise LookupError("Catalog with name \"%s\" not configured!" % name)
+            raise LookupError('Catalog with name "%s" not configured!' % name)
         return self._as_catalog(catalog_dict)
 
     def get_by_path(self, path) -> Catalog:
         path = str(path)
         catalog_dict = self._get_collection_index().get_catalog_by_path(path)
         if not catalog_dict:
-            raise LookupError("Catalog with path \"%s\" not configured!" % path)
+            raise LookupError('Catalog with path "%s" not configured!' % path)
         return self._as_catalog(catalog_dict)
 
     def get_all(self) -> List[Catalog]:
@@ -140,7 +159,9 @@ class CatalogHandler(ICatalogHandler):
                 break
 
         if local_catalog is None:
-            raise RuntimeError("Misconfiguration of catalogs. There must be at least one local catalog!")
+            raise RuntimeError(
+                "Misconfiguration of catalogs. There must be at least one local catalog!"
+            )
 
         return local_catalog
 
@@ -149,10 +170,15 @@ class CatalogHandler(ICatalogHandler):
         if not local_path.exists():
             local_path.mkdir(parents=True)
 
-        meta_data = "{\"name\": \"" + name \
-                    + "\", \"version\": \"" + CatalogIndex.version \
-                    + "\", \"type\": \"" + catalog_type \
-                    + "\"}"
+        meta_data = (
+            '{\"name\": \"'
+            + name
+            + '\", \"version\": \"'
+            + DefaultValues.catalog_index_db_version.value
+            + '\", \"type\": \"'
+            + catalog_type
+            + '\"}'
+            )
         with open(local_path.joinpath(DefaultValues.catalog_index_metafile_json.value), 'w') as meta:
             meta.writelines(meta_data)
 
@@ -160,7 +186,7 @@ class CatalogHandler(ICatalogHandler):
 
     def _update(self, catalog: Catalog) -> bool:
         r = self.album.migration_manager().refresh_index(catalog)
-        module_logger().info('Updated catalog %s!' % catalog.name())
+        module_logger().info("Updated catalog %s!" % catalog.name())
         return r
 
     def update_by_name(self, catalog_name) -> bool:
@@ -187,18 +213,27 @@ class CatalogHandler(ICatalogHandler):
         else:
             self.update_all()
 
-    def update_collection(self, catalog_name=None, dry_run: bool = False, override: bool = False) -> \
-            Dict[str, CatalogUpdates]:
+    def update_collection(
+        self, catalog_name=None, dry_run: bool = False, override: bool = False
+    ) -> Dict[str, CatalogUpdates]:
         if dry_run:
             if catalog_name:
                 catalog = self.get_by_name(catalog_name)
-                return {catalog_name: self._get_divergence_between_catalog_and_collection(catalog)}
+                return {
+                    catalog_name: self._get_divergence_between_catalog_and_collection(
+                        catalog
+                    )
+                }
             else:
                 return self._get_divergence_between_catalogs_and_collection()
         else:
             if catalog_name:
                 catalog = self.get_by_name(catalog_name)
-                return {catalog_name: self._update_collection_from_catalog(catalog, override)}
+                return {
+                    catalog_name: self._update_collection_from_catalog(
+                        catalog, override
+                    )
+                }
             else:
                 return self._update_collection_from_catalogs(override)
 
@@ -214,7 +249,9 @@ class CatalogHandler(ICatalogHandler):
         installed_solutions = self.get_installed_solutions(catalog_to_remove)
 
         if installed_solutions:
-            installed_solutions_string = ", ".join([str(dict_to_coordinates(i.setup())) for i in installed_solutions])
+            installed_solutions_string = ", ".join(
+                [str(dict_to_coordinates(i.setup())) for i in installed_solutions]
+            )
             raise RuntimeError(
                 "Cannot remove catalog! "
                 "Has the following solutions installed: %s" % installed_solutions_string
@@ -232,7 +269,9 @@ class CatalogHandler(ICatalogHandler):
         catalog_dict = self._get_collection_index().get_catalog_by_path(path)
 
         if not catalog_dict:
-            module_logger().warning("Cannot remove catalog, catalog with path %s not found!" % str(path))
+            module_logger().warning(
+                "Cannot remove catalog, catalog with path %s not found!" % str(path)
+            )
             return None
 
         catalog_to_remove = self._remove_from_collection(catalog_dict)
@@ -245,7 +284,9 @@ class CatalogHandler(ICatalogHandler):
         catalog_dict = self._get_collection_index().get_catalog_by_name(name)
 
         if not catalog_dict:
-            module_logger().warning("Cannot remove catalog, catalog with name \"%s\", not found!" % str(name))
+            module_logger().warning(
+                'Cannot remove catalog, catalog with name "%s", not found!' % str(name)
+            )
             return None
 
         catalog_to_remove = self._remove_from_collection(catalog_dict)
@@ -259,13 +300,17 @@ class CatalogHandler(ICatalogHandler):
             if Path(src).exists():
                 src = str(Path(src).resolve())
             else:
-                module_logger().warning("Cannot remove catalog with source \"%s\"! Not configured!" % str(src))
+                module_logger().warning(
+                    'Cannot remove catalog with source "%s"! Not configured!' % str(src)
+                )
                 return None
 
         catalog_dict = self._get_collection_index().get_catalog_by_src(src)
 
         if not catalog_dict:
-            module_logger().warning("Cannot remove catalog with source \"%s\"! Not configured!" % str(src))
+            module_logger().warning(
+                'Cannot remove catalog with source "%s"! Not configured!' % str(src)
+            )
             return None
 
         catalog_to_remove = self._remove_from_collection(catalog_dict)
@@ -275,15 +320,15 @@ class CatalogHandler(ICatalogHandler):
         return catalog_to_remove
 
     def get_installed_solutions(self, catalog: ICatalog):
-        installed_solutions = self._get_collection_index().get_all_installed_solutions_by_catalog(
-            catalog.catalog_id()
+        installed_solutions = (
+            self._get_collection_index().get_all_installed_solutions_by_catalog(
+                catalog.catalog_id()
+            )
         )
         return installed_solutions
 
     def get_all_as_dict(self) -> dict:
-        return {
-            "catalogs": self._get_collection_index().get_all_catalogs()
-        }
+        return {"catalogs": self._get_collection_index().get_all_catalogs()}
 
     def set_version(self, catalog: ICatalog):
         # database version
@@ -291,24 +336,28 @@ class CatalogHandler(ICatalogHandler):
 
         # cache version
         meta_dict = get_dict_from_json(catalog.get_meta_file_path())
-        meta_version = meta_dict['version']
+        meta_version = meta_dict["version"]
 
         if database_version != meta_version:
             raise ValueError(
-                f"Catalog meta information (version {meta_version}) unequal to actual version {database_version}!")
+                f"Catalog meta information (version {meta_version}) unequal to actual version {database_version}!"
+            )
 
         catalog.set_version(database_version)
         return database_version
 
     def _retrieve_catalog_meta_information(self, source, branch_name="main"):
         with TemporaryDirectory(dir=self.album.configuration().tmp_path()) as tmp_dir:
-            repo = Path(tmp_dir).joinpath('repo')
+            repo = Path(tmp_dir).joinpath("repo")
             try:
-                _, meta_src = retrieve_index_files_from_src(source, branch_name=branch_name, tmp_dir=repo)
+                _, meta_src = retrieve_index_files_from_src(
+                    source, branch_name=branch_name, tmp_dir=repo
+                )
                 meta_file = copy(
-                    meta_src, self.album.configuration().cache_path_download().joinpath(
-                        DefaultValues.catalog_index_metafile_json.value
-                    )
+                    meta_src,
+                    self.album.configuration()
+                    .cache_path_download()
+                    .joinpath(DefaultValues.catalog_index_metafile_json.value),
                 )
             finally:
                 force_remove(repo)
@@ -317,10 +366,14 @@ class CatalogHandler(ICatalogHandler):
 
         return meta_dict
 
-    def _create_catalog_from_src(self, src, catalog_meta_information, branch_name="main", deletable=True) -> Catalog:
+    def _create_catalog_from_src(
+        self, src, catalog_meta_information, branch_name="main", deletable=True
+    ) -> Catalog:
         """Creates the local cache path for a catalog given its src. (Network drive, git-link, etc.)"""
         # the path where the catalog lives based on its metadata
-        catalog_path = self.album.configuration().get_cache_path_catalog(catalog_meta_information["name"])
+        catalog_path = self.album.configuration().get_cache_path_catalog(
+            catalog_meta_information["name"]
+        )
 
         catalog = Catalog(
             None,
@@ -329,7 +382,7 @@ class CatalogHandler(ICatalogHandler):
             src=src,
             branch_name=branch_name,
             catalog_type=catalog_meta_information["type"],
-            deletable=deletable
+            deletable=deletable,
         )
 
         catalog.dispose()
@@ -342,14 +395,20 @@ class CatalogHandler(ICatalogHandler):
         if not catalog.path().exists():
             catalog.path().mkdir(parents=True)
 
-    def _get_divergence_between_catalogs_and_collection(self) -> Dict[str, CatalogUpdates]:
+    def _get_divergence_between_catalogs_and_collection(
+        self,
+    ) -> Dict[str, CatalogUpdates]:
         """Gets the divergence list between all catalogs and the catalog_collection."""
         res = {}
         for catalog in self.get_all():
-            res[catalog.name()] = self._get_divergence_between_catalog_and_collection(catalog=catalog)
+            res[catalog.name()] = self._get_divergence_between_catalog_and_collection(
+                catalog=catalog
+            )
         return res
 
-    def _get_divergence_between_catalog_and_collection(self, catalog: Catalog) -> CatalogUpdates:
+    def _get_divergence_between_catalog_and_collection(
+        self, catalog: Catalog
+    ) -> CatalogUpdates:
         """Gets the divergence between a given catalog and the catalog_collection"""
 
         if catalog.is_cache():
@@ -357,19 +416,28 @@ class CatalogHandler(ICatalogHandler):
             return CatalogUpdates(catalog)
 
         solutions_in_collection = self._get_collection_index().get_solutions_by_catalog(
-            catalog.catalog_id())
+            catalog.catalog_id()
+        )
         self.album.migration_manager().load_index(catalog)
         solutions_in_catalog = catalog.index().get_all_solutions()
-        solution_changes = self._compare_solutions(solutions_in_collection, solutions_in_catalog)
+        solution_changes = self._compare_solutions(
+            solutions_in_collection, solutions_in_catalog
+        )
         return CatalogUpdates(catalog, solution_changes=solution_changes)
 
-    def _update_collection_from_catalogs(self, override: bool = False) -> Dict[str, CatalogUpdates]:
+    def _update_collection_from_catalogs(
+        self, override: bool = False
+    ) -> Dict[str, CatalogUpdates]:
         res = {}
         for catalog in self.get_all():
-            res[catalog.name()] = self._update_collection_from_catalog(catalog, override)
+            res[catalog.name()] = self._update_collection_from_catalog(
+                catalog, override
+            )
         return res
 
-    def _update_collection_from_catalog(self, catalog: Catalog, override: bool = False) -> CatalogUpdates:
+    def _update_collection_from_catalog(
+        self, catalog: Catalog, override: bool = False
+    ) -> CatalogUpdates:
         divergence = self._get_divergence_between_catalog_and_collection(catalog)
         # TODO apply changes to catalog attributes
         for change in divergence.solution_changes():
@@ -377,8 +445,10 @@ class CatalogHandler(ICatalogHandler):
         return divergence
 
     @staticmethod
-    def _compare_solutions(solutions_old: List[CollectionIndex.CollectionSolution], solutions_new: List[dict]) -> List[
-        SolutionChange]:
+    def _compare_solutions(
+        solutions_old: List[CollectionIndex.CollectionSolution],
+        solutions_new: List[dict],
+    ) -> List[SolutionChange]:
         res = []
         # CAUTION: solutions should not be compared based on their id as this might change
 
@@ -399,9 +469,13 @@ class CatalogHandler(ICatalogHandler):
 
             # solution updated or added
             if hash not in list_old_hash:
-                if coordinates in dict_old_coordinates.keys():  # changed when metadata in old solution list
+                if (
+                    coordinates in dict_old_coordinates.keys()
+                ):  # changed when metadata in old solution list
                     change = SolutionChange(
-                        coordinates, ChangeType.CHANGED, solution_status=dict_old_coordinates[coordinates].internal()
+                        coordinates,
+                        ChangeType.CHANGED,
+                        solution_status=dict_old_coordinates[coordinates].internal(),
                     )
                     res.append(change)
 
@@ -425,11 +499,11 @@ class CatalogHandler(ICatalogHandler):
     @staticmethod
     def _as_catalog(catalog_dict) -> Catalog:
         return Catalog(
-            catalog_dict['catalog_id'],
-            catalog_dict['name'],
-            catalog_dict['path'],
-            catalog_dict['src'],
-            bool(catalog_dict['deletable']),
-            catalog_dict['branch_name'],
-            catalog_dict['type']
+            catalog_dict["catalog_id"],
+            catalog_dict["name"],
+            catalog_dict["path"],
+            catalog_dict["src"],
+            bool(catalog_dict["deletable"]),
+            catalog_dict["branch_name"],
+            catalog_dict["type"],
         )
