@@ -4,16 +4,22 @@ from typing import Optional, List
 
 from album.core.api.model.catalog_index import ICatalogIndex
 from album.core.model.database import Database
-from album.core.utils.operations.file_operations import get_dict_entry, write_dict_to_json
-from album.core.utils.operations.solution_operations import get_solution_hash, serialize_json
+from album.core.utils.operations.file_operations import (
+    get_dict_entry,
+    write_dict_to_json,
+)
+from album.core.utils.operations.solution_operations import (
+    get_solution_hash,
+    serialize_json,
+)
 from album.runner import album_logging
 from album.runner.core.api.model.coordinates import ICoordinates
+from album.core.model.default_values import DefaultValues
 
 module_logger = album_logging.get_active_logger
 
 
 class CatalogIndex(ICatalogIndex, Database):
-    version = "0.1.0"
 
     def __init__(self, name, path):
         """Init routine.
@@ -29,12 +35,12 @@ class CatalogIndex(ICatalogIndex, Database):
         super().__init__(path)
 
     def create(self):
-        data = pkgutil.get_data('album.core.schema', 'catalog_index_schema.sql')
+        data = pkgutil.get_data("album.core.schema", "catalog_index_schema.sql")
 
         cursor = self.get_cursor()
         cursor.executescript(data.decode("utf-8"))
 
-        self.update_name_version(self.name, self.version, close=False)
+        self.update_name_version(self.name, DefaultValues.catalog_index_db_version.value, close=False)
 
         # explicitly commit and close
         self.close_current_connection(commit=True)
@@ -51,7 +57,9 @@ class CatalogIndex(ICatalogIndex, Database):
     # ### catalog_index ###
 
     def update_name_version(self, name, version, close=True):
-        module_logger().debug("Update index name: \"%s\" and version: \"%s\"" % (name, version))
+        module_logger().debug(
+            'Update index name: "%s" and version: "%s"' % (name, version)
+        )
 
         curr_name = self.get_name()
 
@@ -59,12 +67,11 @@ class CatalogIndex(ICatalogIndex, Database):
         if curr_name:
             cursor.execute(
                 "UPDATE catalog_index SET name=:name, version=:version WHERE name_id=:name_id",
-                {"name_id": 1, "name": name, "version": version}
+                {"name_id": 1, "name": name, "version": version},
             )
         else:
             cursor.execute(
-                "INSERT INTO catalog_index values (?, ?, ?)",
-                (1, name, version)
+                "INSERT INTO catalog_index values (?, ?, ?)", (1, name, version)
             )
 
         if close:
@@ -74,9 +81,7 @@ class CatalogIndex(ICatalogIndex, Database):
         module_logger().debug("Get catalog name...")
 
         cursor = self.get_cursor()
-        r = cursor.execute(
-            "SELECT * FROM catalog_index"
-        ).fetchone()
+        r = cursor.execute("SELECT * FROM catalog_index").fetchone()
 
         cur_name = r["name"] if r else None
 
@@ -89,9 +94,7 @@ class CatalogIndex(ICatalogIndex, Database):
         module_logger().debug("Get index version...")
 
         cursor = self.get_cursor()
-        r = cursor.execute(
-            "SELECT * FROM catalog_index"
-        ).fetchone()
+        r = cursor.execute("SELECT * FROM catalog_index").fetchone()
 
         cur_version = r["version"] if r else None
 
@@ -104,9 +107,7 @@ class CatalogIndex(ICatalogIndex, Database):
         module_logger().debug("Retrieve all solutions...")
 
         cursor = self.get_cursor()
-        r = cursor.execute(
-            "SELECT * FROM solution",
-            {}).fetchall()
+        r = cursor.execute("SELECT * FROM solution", {}).fetchall()
 
         solutions = []
         if r:
@@ -122,8 +123,20 @@ class CatalogIndex(ICatalogIndex, Database):
 
     @staticmethod
     def get_solution_column_keys():
-        return ['group', 'name', 'description', 'version', 'album_api_version', 'album_version', 'license',
-                'acknowledgement', 'title', 'timestamp', 'doi', 'changelog']
+        return [
+            "group",
+            "name",
+            "description",
+            "version",
+            "album_api_version",
+            "album_version",
+            "license",
+            "acknowledgement",
+            "title",
+            "timestamp",
+            "doi",
+            "changelog",
+        ]
 
     def _insert_solution(self, solution_attrs, close=True) -> int:
         hash_val = get_solution_hash(solution_attrs, self.get_solution_column_keys())
@@ -131,106 +144,86 @@ class CatalogIndex(ICatalogIndex, Database):
 
         cursor = self.get_cursor()
         cursor.execute(
-            'INSERT INTO solution values (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)',
+            "INSERT INTO solution values (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)",
             (
                 solution_id,
-                solution_attrs['group'],
-                solution_attrs['name'],
-                get_dict_entry(solution_attrs, 'title'),
-                solution_attrs['version'],
+                solution_attrs["group"],
+                solution_attrs["name"],
+                get_dict_entry(solution_attrs, "title"),
+                solution_attrs["version"],
                 datetime.now().isoformat(),
-                get_dict_entry(solution_attrs, 'description'),
-                get_dict_entry(solution_attrs, 'doi'),  # allow to be none
-                get_dict_entry(solution_attrs, 'license'),
-                get_dict_entry(solution_attrs, 'album_version'),
-                get_dict_entry(solution_attrs, 'album_api_version'),
-                get_dict_entry(solution_attrs, 'changelog'),  # allow to be none
-                get_dict_entry(solution_attrs, 'acknowledgement'),
-                hash_val
-            )
+                get_dict_entry(solution_attrs, "description"),
+                get_dict_entry(solution_attrs, "doi"),  # allow to be none
+                get_dict_entry(solution_attrs, "license"),
+                get_dict_entry(solution_attrs, "album_version"),
+                get_dict_entry(solution_attrs, "album_api_version"),
+                get_dict_entry(solution_attrs, "changelog"),  # allow to be none
+                get_dict_entry(solution_attrs, "acknowledgement"),
+                hash_val,
+            ),
         )
-        if 'authors' in solution_attrs:
-            for author in solution_attrs['authors']:
+        if "solution_creators" in solution_attrs:
+            for author in solution_attrs["solution_creators"]:
                 author_id = self._exists_author(author, close=False)
                 if not author_id:
                     author_id = self._insert_author(author, close=False)
-                solution_author_id = self.next_id('solution_author')
+                solution_author_id = self.next_id("solution_author")
                 cursor.execute(
-                    'INSERT INTO solution_author values (?, ?, ?)',
-                    (
-                        solution_author_id,
-                        solution_id,
-                        author_id
-                    )
+                    "INSERT INTO solution_author values (?, ?, ?)",
+                    (solution_author_id, solution_id, author_id),
                 )
 
-        if 'tags' in solution_attrs:
-            for tag in solution_attrs['tags']:
+        if "tags" in solution_attrs:
+            for tag in solution_attrs["tags"]:
                 tag_id = self._exists_tag(tag, close=False)
                 if not tag_id:
                     tag_id = self._insert_tag(tag, close=False)
-                solution_tag_id = self.next_id('solution_tag')
+                solution_tag_id = self.next_id("solution_tag")
                 cursor.execute(
-                    'INSERT INTO solution_tag values (?, ?, ?)',
-                    (
-                        solution_tag_id,
-                        solution_id,
-                        tag_id
-                    )
+                    "INSERT INTO solution_tag values (?, ?, ?)",
+                    (solution_tag_id, solution_id, tag_id),
                 )
 
-        if 'args' in solution_attrs:
-            for argument in solution_attrs['args']:
+        if "args" in solution_attrs:
+            for argument in solution_attrs["args"]:
                 argument_id = self._exists_argument(argument, close=False)
                 if not argument_id:
                     argument_id = self._insert_argument(argument, close=False)
-                solution_argument_id = self.next_id('solution_argument')
+                solution_argument_id = self.next_id("solution_argument")
                 cursor.execute(
-                    'INSERT INTO solution_argument values (?, ?, ?)',
-                    (
-                        solution_argument_id,
-                        solution_id,
-                        argument_id
-                    )
+                    "INSERT INTO solution_argument values (?, ?, ?)",
+                    (solution_argument_id, solution_id, argument_id),
                 )
-        if 'cite' in solution_attrs:
-            for citation in solution_attrs['cite']:
+        if "cite" in solution_attrs:
+            for citation in solution_attrs["cite"]:
                 citation_id = self._exists_citation(citation, close=False)
                 if not citation_id:
                     citation_id = self._insert_citation(citation, close=False)
-                solution_citation_id = self.next_id('solution_citation')
+                solution_citation_id = self.next_id("solution_citation")
                 cursor.execute(
-                    'INSERT INTO solution_citation values (?, ?, ?)',
-                    (
-                        solution_citation_id,
-                        solution_id,
-                        citation_id
-                    )
+                    "INSERT INTO solution_citation values (?, ?, ?)",
+                    (solution_citation_id, solution_id, citation_id),
                 )
 
-        if 'custom' in solution_attrs:
-            for key in solution_attrs['custom']:
-                value = solution_attrs['custom'][key]
+        if "custom" in solution_attrs:
+            for key in solution_attrs["custom"]:
+                value = solution_attrs["custom"][key]
                 custom_id = self._exists_custom_key(key, value, close=False)
                 if not custom_id:
                     custom_id = self._insert_custom_key(key, value, close=False)
-                solution_custom_key_id = self.next_id('solution_custom')
+                solution_custom_key_id = self.next_id("solution_custom")
                 cursor.execute(
-                    'INSERT INTO solution_custom values (?, ?, ?)',
-                    (
-                        solution_custom_key_id,
-                        solution_id,
-                        custom_id
-                    )
+                    "INSERT INTO solution_custom values (?, ?, ?)",
+                    (solution_custom_key_id, solution_id, custom_id),
                 )
 
-        if 'covers' in solution_attrs:
-            for cover in solution_attrs['covers']:
+        if "covers" in solution_attrs:
+            for cover in solution_attrs["covers"]:
                 if not self._exists_cover(cover, solution_id):
                     self._insert_cover(cover, solution_id, close=False)
 
-        if 'documentation' in solution_attrs:
-            for documentation in solution_attrs['documentation']:
+        if "documentation" in solution_attrs:
+            for documentation in solution_attrs["documentation"]:
                 if not self._exists_documentation(documentation, solution_id):
                     self._insert_documentation(documentation, solution_id, close=False)
 
@@ -244,10 +237,7 @@ class CatalogIndex(ICatalogIndex, Database):
     def _exists_author(self, author_name, close=True):
         cursor = self.get_cursor()
         r = cursor.execute(
-            "SELECT * FROM author WHERE name=:author_name",
-            {
-                "author_name": author_name
-            }
+            "SELECT * FROM author WHERE name=:author_name", {"author_name": author_name}
         ).fetchone()
 
         if close:
@@ -259,13 +249,7 @@ class CatalogIndex(ICatalogIndex, Database):
         author_id = self.next_id("author")
 
         cursor = self.get_cursor()
-        cursor.execute(
-            "INSERT INTO author values (?, ?)",
-            (
-                author_id,
-                author
-            )
-        )
+        cursor.execute("INSERT INTO author values (?, ?)", (author_id, author))
 
         if close:
             self.close_current_connection()
@@ -275,10 +259,7 @@ class CatalogIndex(ICatalogIndex, Database):
     def _exists_tag(self, tag_name, close=True):
         cursor = self.get_cursor()
         r = cursor.execute(
-            "SELECT * FROM tag WHERE name=:tag_name ",
-            {
-                "tag_name": tag_name
-            }
+            "SELECT * FROM tag WHERE name=:tag_name ", {"tag_name": tag_name}
         ).fetchone()
 
         if close:
@@ -290,14 +271,7 @@ class CatalogIndex(ICatalogIndex, Database):
         tag_id = self.next_id("tag")
 
         cursor = self.get_cursor()
-        cursor.execute(
-            "INSERT INTO tag values (?, ?, ?)",
-            (
-                tag_id,
-                tag,
-                "manual"
-            )
-        )
+        cursor.execute("INSERT INTO tag values (?, ?, ?)", (tag_id, tag, "manual"))
 
         if close:
             self.close_current_connection()
@@ -313,7 +287,7 @@ class CatalogIndex(ICatalogIndex, Database):
             "argument_description": argument["description"],
         }
         argument_type = get_dict_entry(argument, "type")
-        argument_default_value = get_dict_entry(argument, "default_value")
+        argument_default_value = get_dict_entry(argument, "default")
 
         if argument_type:
             exc_str += "AND type=:argument_type "
@@ -360,10 +334,10 @@ class CatalogIndex(ICatalogIndex, Database):
                 argument_id,
                 argument["name"],
                 get_dict_entry(argument, "type"),
-                argument["description"],
-                get_dict_entry(argument, "default_value"),
-                get_dict_entry(argument, "required")
-            )
+                get_dict_entry(argument, "description"),
+                get_dict_entry(argument, "default"),
+                get_dict_entry(argument, "required"),
+            ),
         )
 
         if close:
@@ -376,12 +350,7 @@ class CatalogIndex(ICatalogIndex, Database):
 
         cursor = self.get_cursor()
         cursor.execute(
-            "INSERT INTO custom values (?, ?, ?)",
-            (
-                custom_id,
-                custom_key,
-                custom_value
-            )
+            "INSERT INTO custom values (?, ?, ?)", (custom_id, custom_key, custom_value)
         )
 
         if close:
@@ -420,8 +389,8 @@ class CatalogIndex(ICatalogIndex, Database):
                 citation_id,
                 citation["text"],
                 get_dict_entry(citation, "doi"),
-                get_dict_entry(citation, "url")
-            )
+                get_dict_entry(citation, "url"),
+            ),
         )
 
         if close:
@@ -437,8 +406,8 @@ class CatalogIndex(ICatalogIndex, Database):
             {
                 "cover_source": cover["source"],
                 "cover_description": cover["description"],
-                "solution_id": solution_id
-            }
+                "solution_id": solution_id,
+            },
         ).fetchone()
 
         if close:
@@ -452,12 +421,7 @@ class CatalogIndex(ICatalogIndex, Database):
         cursor = self.get_cursor()
         cursor.execute(
             "INSERT INTO cover values (?, ?, ?, ?)",
-            (
-                cover_id,
-                solution_id,
-                cover["source"],
-                cover["description"]
-            )
+            (cover_id, solution_id, cover["source"], cover["description"]),
         )
 
         if close:
@@ -473,7 +437,7 @@ class CatalogIndex(ICatalogIndex, Database):
             {
                 "documentation": documentation,
                 "solution_id": solution_id,
-            }
+            },
         ).fetchone()
 
         if close:
@@ -486,11 +450,7 @@ class CatalogIndex(ICatalogIndex, Database):
         cursor = self.get_cursor()
         cursor.execute(
             "INSERT INTO documentation values (?, ?, ?)",
-            (
-                documentation_id,
-                solution_id,
-                documentation
-            )
+            (documentation_id, solution_id, documentation),
         )
 
         if close:
@@ -499,14 +459,15 @@ class CatalogIndex(ICatalogIndex, Database):
         return documentation_id
 
     def get_solution(self, solution_id, close=True) -> Optional[dict]:
-        module_logger().debug("Get solution by id: \"%s\"..." % solution_id)
+        module_logger().debug('Get solution by id: "%s"...' % solution_id)
 
         cursor = self.get_cursor()
         r = cursor.execute(
             "SELECT * FROM solution WHERE solution_id=:solution_id",
             {
                 "solution_id": solution_id,
-            }).fetchone()
+            },
+        ).fetchone()
         solution = None
         if r:
             solution = dict(r)
@@ -517,18 +478,20 @@ class CatalogIndex(ICatalogIndex, Database):
 
         return solution
 
-    def get_solution_by_coordinates(self, coordinates: ICoordinates, close=True) -> Optional[dict]:
-        module_logger().debug("Get solution by coordinates: \"%s\"..." % str(coordinates))
+    def get_solution_by_coordinates(
+        self, coordinates: ICoordinates, close=True
+    ) -> Optional[dict]:
+        module_logger().debug('Get solution by coordinates: "%s"...' % str(coordinates))
 
         cursor = self.get_cursor()
         r = cursor.execute(
             "SELECT s.* FROM solution s "
-            "WHERE s.\"group\"=:group AND s.name=:name AND s.version=:version",
+            'WHERE s."group"=:group AND s.name=:name AND s.version=:version',
             {
                 "group": coordinates.group(),
                 "name": coordinates.name(),
                 "version": coordinates.version(),
-            }
+            },
         ).fetchone()
 
         solution = None
@@ -543,7 +506,7 @@ class CatalogIndex(ICatalogIndex, Database):
 
     def _append_metadata_to_solution_dict(self, solution):
         solution_id = solution["solution_id"]
-        solution["authors"] = self._get_authors_by_solution(solution_id)
+        solution["solution_creators"] = self._get_authors_by_solution(solution_id)
         solution["covers"] = self._get_covers_by_solution(solution_id)
         solution["documentation"] = self._get_documentation_by_solution(solution_id)
         solution["args"] = self._get_arguments_by_solution(solution_id)
@@ -552,14 +515,14 @@ class CatalogIndex(ICatalogIndex, Database):
         solution["custom"] = self._get_custom_by_solution(solution_id)
 
     def get_solution_by_doi(self, doi, close=True) -> Optional[dict]:
-        module_logger().debug("Get solution by doi: \"%s\"..." % doi)
+        module_logger().debug('Get solution by doi: "%s"...' % doi)
 
         cursor = self.get_cursor()
         r = cursor.execute(
             "SELECT * FROM solution WHERE doi=:doi_value",
             {
                 "doi_value": doi,
-            }
+            },
         ).fetchone()
 
         solution = None
@@ -571,16 +534,20 @@ class CatalogIndex(ICatalogIndex, Database):
 
         return solution
 
-    def get_all_solution_versions(self, group, name, close=True) -> Optional[List[dict]]:
-        module_logger().debug("Get solution by group and name: \"%s:%s\"..." % (group, name))
+    def get_all_solution_versions(
+        self, group, name, close=True
+    ) -> Optional[List[dict]]:
+        module_logger().debug(
+            'Get solution by group and name: "%s:%s"...' % (group, name)
+        )
 
         cursor = self.get_cursor()
         r = cursor.execute(
-            "SELECT * FROM solution WHERE \"group\"=:group_value AND name=:name_value ORDER BY version DESC",
+            'SELECT * FROM solution WHERE "group"=:group_value AND name=:name_value ORDER BY version DESC',
             {
                 "group_value": group,
                 "name_value": name,
-            }
+            },
         ).fetchall()
 
         solutions = []
@@ -593,102 +560,96 @@ class CatalogIndex(ICatalogIndex, Database):
 
         return solutions
 
-    def _update_solution(self, coordinates: ICoordinates, solution_attrs: dict, close=True) -> None:
-        # it is easier to delete and insert again instead of updating all connection-tables
-        solution_dict = self.get_solution_by_coordinates(coordinates, close=False)
-        if solution_dict:
-            self.remove_solution(solution_dict["solution_id"])
-        else:
-            raise RuntimeError("Cannot update solution \"%s\"! Does not exist!" % str(coordinates))
+    def _update_solution(
+        self, coordinates: ICoordinates, solution_attrs: dict, close=True
+    ) -> None:
+        try:
+            # it is easier to delete and insert again instead of updating all connection-tables
+            solution_dict = self.get_solution_by_coordinates(coordinates, close=False)
+            if solution_dict:
+                self.remove_solution(solution_dict["solution_id"])
+            else:
+                raise RuntimeError(
+                    'Cannot update solution "%s"! Does not exist!' % str(coordinates)
+                )
 
-        self._insert_solution(solution_attrs, close=False)
+            self._insert_solution(solution_attrs, close=False)
 
-        self.save()
-
-        if close:
-            self.close_current_connection()
+            self.save()
+        finally:
+            if close:
+                self.close_current_connection()
 
     def remove_solution(self, solution_id, close=True):
         cursor = self.get_cursor()
 
         cursor.execute(
             "DELETE FROM cover WHERE solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         )
         cursor.execute(
             "DELETE FROM documentation WHERE solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         )
 
         cursor.execute(
             "DELETE FROM solution_tag WHERE solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         )
 
         cursor.execute(
             "DELETE FROM solution_author WHERE solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         )
 
         cursor.execute(
             "DELETE FROM solution_citation WHERE solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         )
 
         cursor.execute(
             "DELETE FROM solution_argument WHERE solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         )
 
         cursor.execute(
             "DELETE FROM solution_custom WHERE solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         )
 
         cursor.execute(
             "DELETE FROM tag "
             "WHERE NOT EXISTS (SELECT st.tag_id FROM solution_tag st "
-            "WHERE tag.tag_id = st.tag_id)")
+            "WHERE tag.tag_id = st.tag_id)"
+        )
 
         cursor.execute(
             "DELETE FROM argument "
             "WHERE NOT EXISTS (SELECT sa.argument_id FROM solution_argument sa "
-            "WHERE argument.argument_id = sa.argument_id)")
+            "WHERE argument.argument_id = sa.argument_id)"
+        )
 
         cursor.execute(
             "DELETE FROM citation "
             "WHERE NOT EXISTS (SELECT sc.citation_id FROM solution_citation sc "
-            "WHERE citation.citation_id = sc.citation_id)")
+            "WHERE citation.citation_id = sc.citation_id)"
+        )
 
         cursor.execute(
             "DELETE FROM author "
             "WHERE NOT EXISTS (SELECT sa.author_id FROM solution_author sa "
-            "WHERE author.author_id = sa.author_id)")
+            "WHERE author.author_id = sa.author_id)"
+        )
 
         cursor.execute(
             "DELETE FROM custom "
             "WHERE NOT EXISTS (SELECT sa.custom_id FROM solution_custom sa "
-            "WHERE custom.custom_id = sa.custom_id)")
+            "WHERE custom.custom_id = sa.custom_id)"
+        )
 
         cursor.execute(
             "DELETE FROM solution WHERE solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         )
 
         self.save()
@@ -696,7 +657,9 @@ class CatalogIndex(ICatalogIndex, Database):
         if close:
             self.close_current_connection()
 
-    def remove_solution_by_group_name_version(self, coordinates: ICoordinates, close=True):
+    def remove_solution_by_group_name_version(
+        self, coordinates: ICoordinates, close=True
+    ):
         solution_dict = self.get_solution_by_coordinates(coordinates, close=close)
         if solution_dict:
             self.remove_solution(solution_dict["solution_id"])
@@ -732,7 +695,7 @@ class CatalogIndex(ICatalogIndex, Database):
 
             write_dict_to_json(path, json_dumps_list)
         else:
-            raise NotImplementedError("Unsupported format \"%s\"" % export_format)
+            raise NotImplementedError('Unsupported format "%s"' % export_format)
 
         if close:
             self.close_current_connection()
@@ -753,9 +716,7 @@ class CatalogIndex(ICatalogIndex, Database):
             "SELECT a.* FROM author a "
             "JOIN solution_author sa ON sa.author_id = a.author_id "
             "WHERE sa.solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         ).fetchall()
 
         res = []
@@ -773,9 +734,7 @@ class CatalogIndex(ICatalogIndex, Database):
             "SELECT t.* FROM tag t "
             "JOIN solution_tag st ON st.tag_id = t.tag_id "
             "WHERE st.solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         ).fetchall()
 
         res = []
@@ -793,9 +752,7 @@ class CatalogIndex(ICatalogIndex, Database):
             "SELECT c.* FROM citation c "
             "JOIN solution_citation sc ON sc.citation_id = c.citation_id "
             "WHERE sc.solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         ).fetchall()
 
         res = []
@@ -813,14 +770,20 @@ class CatalogIndex(ICatalogIndex, Database):
             "SELECT a.* FROM argument a "
             "JOIN solution_argument sa ON sa.argument_id = a.argument_id "
             "WHERE sa.solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         ).fetchall()
 
         res = []
         for row in r:
-            res.append(dict(row))
+            row = dict(row)
+            argument = {"name": row["name"], "type": row["type"]}
+            if "description" in row and row["description"] is not None:
+                argument["description"] = row["description"]
+            if "required" in row and row["required"] is not None:
+                argument["required"] = bool(row["required"])
+            if "default_value" in row and row["default_value"] is not None:
+                argument["default"] = row["default_value"]
+            res.append(argument)
 
         if close:
             self.close_current_connection()
@@ -833,15 +796,13 @@ class CatalogIndex(ICatalogIndex, Database):
             "SELECT a.* FROM custom a "
             "JOIN solution_custom sa ON sa.custom_id = a.custom_id "
             "WHERE sa.solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            {"solution_id": solution_id},
         ).fetchall()
 
         res = {}
         for row in r:
             dict_row = dict(row)
-            res[row['custom_key']] = row['custom_value']
+            res[row["custom_key"]] = row["custom_value"]
 
         if close:
             self.close_current_connection()
@@ -851,11 +812,8 @@ class CatalogIndex(ICatalogIndex, Database):
     def _get_covers_by_solution(self, solution_id, close=True):
         cursor = self.get_cursor()
         r = cursor.execute(
-            "SELECT c.* FROM cover c "
-            "WHERE c.solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            "SELECT c.* FROM cover c " "WHERE c.solution_id=:solution_id",
+            {"solution_id": solution_id},
         ).fetchall()
 
         res = []
@@ -870,11 +828,8 @@ class CatalogIndex(ICatalogIndex, Database):
     def _get_documentation_by_solution(self, solution_id, close=True):
         cursor = self.get_cursor()
         r = cursor.execute(
-            "SELECT d.* FROM documentation d "
-            "WHERE d.solution_id=:solution_id",
-            {
-                "solution_id": solution_id
-            }
+            "SELECT d.* FROM documentation d " "WHERE d.solution_id=:solution_id",
+            {"solution_id": solution_id},
         ).fetchall()
 
         res = []
