@@ -8,7 +8,11 @@ from requests.adapters import HTTPAdapter
 from urllib3.util import Retry
 
 from album.ci.utils.zenodo_api import ResponseStatus
-from album.core.utils.operations.file_operations import create_path_recursively, copy, check_zip
+from album.core.utils.operations.file_operations import (
+    create_path_recursively,
+    copy,
+    check_zip,
+)
 
 module_logger = album_logging.get_active_logger
 
@@ -18,8 +22,8 @@ def is_downloadable(url):
     with _get_session() as s:
         h = s.head(url, allow_redirects=True)
         header = h.headers
-        content_type = header.get('content-type')
-        if 'html' in content_type.lower():
+        content_type = header.get("content-type")
+        if "html" in content_type.lower():
             return False
         return True
 
@@ -31,7 +35,7 @@ def download_resource(url, path):
     path = Path(path)
 
     if not is_downloadable(url):
-        raise AssertionError("Resource \"%s\" not downloadable!" % url)
+        raise AssertionError('Resource "%s" not downloadable!' % url)
 
     r = _request_get(url)
 
@@ -49,8 +53,8 @@ def _get_session():
 
     adapter = HTTPAdapter(max_retries=retry)
 
-    s.mount('http://', adapter)
-    s.mount('https://', adapter)
+    s.mount("http://", adapter)
+    s.mount("https://", adapter)
 
     return s
 
@@ -79,15 +83,28 @@ def retrieve_redirect_url(url):
 def is_url(str_input: str):
     """Parses a url."""
     url_regex = re.compile(
-        r'^(?:http|ftp)s?://'  # http:// or https://
-        r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|'  # domain...
-        r'localhost|'  # localhost...
-        r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})'  # ...or ip
-        r'(?::\d+)?'  # optional port
-        r'(?:/?|[/?]\S+)$', re.IGNORECASE)
+        r"^(?:http|ftp)s?://"  # http:// or https://
+        r"(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|"  # domain...
+        r"localhost|"  # localhost...
+        r"\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})"  # ...or ip
+        r"(?::\d+)?"  # optional port
+        r"(?:/?|[/?]\S+)$",
+        re.IGNORECASE,
+    )
     return re.match(url_regex, str_input) is not None
 
 
+def is_git_ssh_address(str_input: str):
+    """Parses a ssh address."""
+    git_regex = re.compile(
+        r"(ssh://){0,1}"  # long ssh address start
+        r"[\S]*@"  # user@
+        r"[\S]*",  # host and project
+        re.IGNORECASE,
+    )
+    return re.match(git_regex, str_input) is not None
+
+
 def download(str_input, base):
     """Downloads a solution file into a temporary file."""
     Path(base).mkdir(exist_ok=True, parents=True)
@@ -96,10 +113,10 @@ def download(str_input, base):
         r = s.get(str_input, allow_redirects=True, stream=True)
 
         new_file, tmp_file_name = tempfile.mkstemp(dir=base)
-        with open(tmp_file_name, 'wb') as out:
+        with open(tmp_file_name, "wb") as out:
             out.write(r.content)
         if check_zip(tmp_file_name):
-            new_file, tmp_file_name_zip = tempfile.mkstemp(dir=base, suffix='.zip')
+            new_file, tmp_file_name_zip = tempfile.mkstemp(dir=base, suffix=".zip")
             copy(tmp_file_name, tmp_file_name_zip)
             return Path(tmp_file_name_zip)
         return Path(tmp_file_name)
